@@ -4,19 +4,18 @@ bilibili_api.ass
 有关 ASS 文件的操作
 """
 import os
-from typing import Union
+from tempfile import gettempdir
+from typing import Union, Optional
 
+from .video import Video
 from .bangumi import Episode
 from .cheese import CheeseVideo
-from .exceptions.ArgsException import ArgsException
-
-from .utils.Credential import Credential
-from .utils.network_httpx import get_session
-from .utils.danmaku2ass import Danmaku2ASS
-from .utils.json2srt import json2srt
 from .utils.srt2ass import srt2ass
-from .video import Video
-from tempfile import gettempdir
+from .utils.json2srt import json2srt
+from .utils.credential import Credential
+from .utils.danmaku2ass import Danmaku2ASS
+from .utils.network_httpx import get_session
+from .exceptions.ArgsException import ArgsException
 
 
 def export_ass_from_xml(
@@ -31,6 +30,7 @@ def export_ass_from_xml(
 ) -> None:
     """
     以一个 XML 文件创建 ASS
+
     一定看清楚 Arguments!
 
     Args:
@@ -64,6 +64,7 @@ def export_ass_from_srt(file_local, output_local) -> None:
 
     Args:
         file_local   (str): 文件位置
+
         output_local (str): 输出位置
     """
     srt2ass(file_local, output_local, "movie")
@@ -75,6 +76,7 @@ def export_ass_from_json(file_local, output_local) -> None:
 
     Args:
         file_local   (str): 文件位置
+
         output_local (str): 输出位置
     """
     json2srt(file_local, output_local.replace(".ass", ".srt"))
@@ -83,26 +85,51 @@ def export_ass_from_json(file_local, output_local) -> None:
 
 
 async def make_ass_file_subtitle(
-    obj: Union[Video, Episode], out="test.ass", name="中文（自动生成）"
+    obj: Union[Video, Episode],
+    page_index: Optional[int] = 0,
+    cid: Optional[int] = None,
+    out: Optional[str] = "test.ass",
+    lan_name: Optional[str] = "中文（自动生成）",
+    lan_code: Optional[str] = "ai-zh",
+    credential: Credential = Credential(),
 ) -> None:
     """
     生成视频字幕文件
 
     Args:
         obj        (Union[Video,Episode]): 对象
+
+        page_index (int, optional)       : 分 P 索引
+
+        cid        (int, optional)       : cid
+
         out        (str, optional)       : 输出位置. Defaults to "test.ass".
-        name       (str, optional)       : 字幕名，如”中文（自动生成）“,是简介的'subtitle'项的'list'项中的弹幕的'lan_doc'属性。Defaults to "中文（自动生成）".
+
+        lan_name   (str, optional)       : 字幕名，如”中文（自动生成）“,是简介的 subtitle 项的'list'项中的弹幕的'lan_doc'属性。Defaults to "中文（自动生成）".
+
+        lan_code   (str, optional)       : 字幕语言代码，如 ”中文（自动翻译）” 和 ”中文（自动生成）“ 为 "ai-zh"
+
+        credential (Credential)          : Credential 类. 必须在此处或传入的视频 obj 中传入凭据，两者均存在则优先此处
     """
+    # 目测必须得有 Credential 才能获取字幕
+    if credential.has_sessdata():
+        obj.credential = credential
+    elif not obj.credential.has_sessdata():
+        raise credential.raise_for_no_sessdata()
+
     if isinstance(obj, Episode):
         info = await obj.get_player_info(cid=await obj.get_cid(), epid=obj.get_epid())
-        json_files = info["subtitle"]["subtitles"]
     else:
-        info = await obj.get_info() 
-        json_files = info["subtitle"]["list"]
+        if cid == None:
+            if page_index == None:
+                raise ArgsException("page_index 和 cid 至少提供一个。")
+            cid = await obj.get_cid(page_index=page_index)
+        info = await obj.get_player_info(cid=cid)
+    json_files = info["subtitle"]["subtitles"]
     for subtitle in json_files:
-        if subtitle["lan_doc"] == name:
+        if subtitle["lan_doc"] == lan_name or subtitle["lan"] == lan_code:
             url = subtitle["subtitle_url"]
-            if isinstance(obj, Episode):
+            if isinstance(obj, Episode) or "https:" not in url:
                 url = "https:" + url
             req = await get_session().request("GET", url)
             file_dir = gettempdir() + "/" + "subtitle.json"
@@ -128,20 +155,32 @@ async def make_ass_file_danmakus_protobuf(
 ) -> None:
     """
     生成视频弹幕文件 *★,°*:.☆(￣▽￣)/$:*.°★* 。
+
     强烈推荐 PotPlayer, 电影与电视全部都是静态的，不能滚动。
+
     来源：protobuf
 
     Args:
         obj         (Union[Video,Episode,CheeseVideo])       : 对象
+
         page        (int, optional)                          : 分 P 号. Defaults to 0.
+
         out         (str, optional)                          : 输出文件. Defaults to "test.ass"
+
         cid         (int | None, optional)                   : cid. Defaults to None.
+
         credential  (Credential | None, optional)            : 凭据. Defaults to None.
+
         date        (datetime.date, optional)                : 获取时间. Defaults to None.
+
         font_name   (str, optional)                          : 字体. Defaults to "Simsun".
+
         font_size   (float, optional)                        : 字体大小. Defaults to 25.0.
+
         alpha       (float, optional)                        : 透明度(0-1). Defaults to 1.
+
         fly_time    (float, optional)                        : 滚动弹幕持续时间. Defaults to 7.
+
         static_time (float, optional)                        : 静态弹幕持续时间. Defaults to 5.
     """
     credential = credential if credential else Credential()
@@ -155,7 +194,8 @@ async def make_ass_file_danmakus_protobuf(
             if cid is None:
                 if page is None:
                     raise ArgsException("page_index 和 cid 至少提供一个。")
-                cid = await v._Video__get_page_id_by_index(page)  # type: ignore
+                # type: ignore
+                cid = await v._Video__get_page_id_by_index(page)
         try:
             info = await v.get_info()
         except:
@@ -206,17 +246,28 @@ async def make_ass_file_danmakus_xml(
 ) -> None:
     """
     生成视频弹幕文件 *★,°*:.☆(￣▽￣)/$:*.°★* 。
+
     强烈推荐 PotPlayer, 电影与电视全部都是静态的，不能滚动。
+
     来源：xml
+
     Args:
         obj         (Union[Video,Episode,Cheese]): 对象
+
         page        (int, optional)              : 分 P 号. Defaults to 0.
+
         out         (str, optional)              : 输出文件. Defaults to "test.ass".
+
         cid         (int | None, optional)       : cid. Defaults to None.
+
         font_name   (str, optional)              : 字体. Defaults to "Simsun".
+
         font_size   (float, optional)            : 字体大小. Defaults to 25.0.
+
         alpha       (float, optional)            : 透明度(0-1). Defaults to 1.
+
         fly_time    (float, optional)            : 滚动弹幕持续时间. Defaults to 7.
+
         static_time (float, optional)            : 静态弹幕持续时间. Defaults to 5.
     """
     if isinstance(obj, Video):
