@@ -5,11 +5,11 @@ bilibili_api.black_room
 """
 
 from enum import Enum
-from typing import Union, Optional, List
+from typing import List, Union, Optional
 
 from .utils.utils import get_api
-from .utils.network_httpx import request
-from .utils.Credential import Credential
+from .utils.credential import Credential
+from .utils.network_httpx import Api
 
 
 class BlackReasonType(Enum):
@@ -125,6 +125,7 @@ class BlackFrom(Enum):
     ADMIN = 1
     ALL = None
 
+
 class JuryVoteOpinion(Enum):
     """
     仲裁投票类型枚举，选择对应案件类型的观点
@@ -141,6 +142,7 @@ class JuryVoteOpinion(Enum):
     - ENV_BAD: 评论环境差
     - ENV_UNKNOW: 无法判断评论环境
     """
+
     SUITABLE = 1
     AVERAGE = 2
     UNSUITABLE = 3
@@ -150,6 +152,7 @@ class JuryVoteOpinion(Enum):
     ENV_BAD = 13
     ENV_UNKNOW = 14
 
+
 API = get_api("black-room")
 
 
@@ -164,8 +167,11 @@ async def get_blocked_list(
 
     Args:
         from_      (BlackFrom)        : 违规来源. Defaults to BlackFrom.ALL.
+
         type_      (int)              : 违规类型. Defaults to BlackType.ALL.
+
         pn         (int)              : 页数. Defaults to 1.
+
         credential (Credential | None): 凭据. Defaults to None.
     """
     credential = credential if credential else Credential()
@@ -173,7 +179,7 @@ async def get_blocked_list(
     params = {"pn": pn, "otype": type_.value}
     if from_.value != None:
         params["btype"] = from_.value
-    return await request("GET", api["url"], params=params, credential=credential)
+    return await Api(**api, credential=credential).update_params(**params).result
 
 
 class BlackRoom:
@@ -188,6 +194,7 @@ class BlackRoom:
         """
         Args:
             black_room_id (int)                        : 小黑屋 id
+
             credential    (Credential | None, optional): 凭据类. Defaults to None.
         """
         self.__id = black_room_id
@@ -202,9 +209,7 @@ class BlackRoom:
         """
         api = API["black_room"]["detail"]
         params = {"id": self.__id}
-        return await request(
-            "GET", api["url"], params=params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def get_reason(self) -> BlackReasonType:
         """
@@ -221,11 +226,13 @@ class BlackRoom:
     async def set_id(self, id_) -> None:
         self.__init__(id_, self.credential)
 
+
 class JuryCase:
     def __init__(self, case_id: str, credential: Credential):
         """
         Args:
             case_id (str)                              : 案件 id
+
             credential (Credential)                    : 凭据类
         """
         self.case_id = case_id
@@ -240,16 +247,15 @@ class JuryCase:
         """
         api = API["jury"]["detail"]
         params = {"case_id": self.case_id}
-        return await request(
-            "GET", api["url"], params=params, credential=self.credential
-        )
-    
+        return await Api(**api, credential=self.credential).update_params(**params).result
+
     async def get_opinions(self, pn: int = 1, ps: int = 20) -> dict:
         """
         获取案件的观点列表
 
         Args:
             pn (int, optional): 页数. Defaults to 1.
+
             ps (int, optional): 每页数量. Defaults to 20.
 
         Returns:
@@ -257,36 +263,42 @@ class JuryCase:
         """
         api = API["jury"]["opinion"]
         params = {"case_id": self.case_id, "pn": pn, "ps": ps}
-        return await request(
-            "GET", api["url"], params=params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
-
-    async def vote(self, opinion: JuryVoteOpinion, is_insider: bool, is_anonymous: bool, reason: Optional[str] = None) -> dict:
+    async def vote(
+        self,
+        opinion: JuryVoteOpinion,
+        is_insider: bool,
+        is_anonymous: bool,
+        reason: Optional[str] = None,
+    ) -> dict:
         """
         进行仲裁投票
 
         Args:
             opinion (JuryVoteOpinion): 投票选项类型
+
             is_insider (bool): 是否观看此类视频
+
             is_anonymous (bool): 是否匿名投票
+
             reason (str, optional): 投票理由. Defaults to None.
 
         Returns:
             dict: 调用 API 返回的结果
         """
         api = API["jury"]["vote"]
-        data = {"case_id": self.case_id, 
-                  "vote": opinion.value, 
-                  "insiders": 1 if is_insider else 0, 
-                  "anonymous": 1 if is_anonymous else 0,
-                  "csrf": self.credential.bili_jct,
-                  }
+        data = {
+            "case_id": self.case_id,
+            "vote": opinion.value,
+            "insiders": 1 if is_insider else 0,
+            "anonymous": 1 if is_anonymous else 0,
+            "csrf": self.credential.bili_jct,
+        }
         if reason:
             data["content"] = reason
-        return await request(
-            "POST", api["url"], data=data, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_data(**data).result
+
 
 async def get_next_jury_case(credential: Credential) -> JuryCase:
     """
@@ -300,15 +312,22 @@ async def get_next_jury_case(credential: Credential) -> JuryCase:
     """
     credential.raise_for_no_sessdata()
     api = API["jury"]["next_case"]
-    return JuryCase((await request("GET", api["url"], credential=credential))["case_id"], credential)
+    return JuryCase(
+        (await Api(**api, credential=credential).result)["case_id"], credential
+    )
 
-async def get_jury_case_list(credential: Credential, pn: int = 1, ps: int = 20) -> List[JuryCase]:
+
+async def get_jury_case_list(
+    credential: Credential, pn: int = 1, ps: int = 20
+) -> List[JuryCase]:
     """
     获取仲裁案件列表
 
     Args:
         credential (Credential): 凭据类
+
         pn (int, optional): 页数. Defaults to 1.
+
         ps (int, optional): 每页数量. Defaults to 20.
 
     Returns:
@@ -316,5 +335,5 @@ async def get_jury_case_list(credential: Credential, pn: int = 1, ps: int = 20)
     """
     api = API["jury"]["case_list"]
     params = {"pn": pn, "ps": ps}
-    info = await request("GET", api["url"], params=params, credential=credential)
-    return [JuryCase(case["case_id"], credential) for case in info["list"]]
\ No newline at end of file
+    info = await Api(**api, credential=credential).update_params(**params).result
+    return [JuryCase(case["case_id"], credential) for case in info["list"]]
