@@ -4,25 +4,24 @@ bilibili_api.dynamic
 动态相关
 """
 
-import json
-import re
 import os
+import re
 import sys
-from typing import Any, List, Tuple, Union, Optional
+import json
+import asyncio
 from enum import Enum
+from datetime import datetime
+from typing import Any, List, Tuple, Union, Optional
 
 import httpx
 
-from .exceptions.DynamicExceedImagesException import DynamicExceedImagesException
-from .utils.network_httpx import request
-from .utils.Credential import Credential
-from .utils.sync import sync
-from . import user, exceptions
 from .utils import utils
-from .utils.Picture import Picture
-from . import vote
-from datetime import datetime
-import asyncio
+from .utils.sync import sync
+from .utils.picture import Picture
+from . import user, vote, exceptions
+from .utils.credential import Credential
+from .utils.network_httpx import Api
+from .exceptions.DynamicExceedImagesException import DynamicExceedImagesException
 
 API = utils.get_api("dynamic")
 
@@ -142,6 +141,7 @@ async def _get_draw_data(
 
     Args:
         text   (str)          : 文本内容
+
         images (List[Picture]): 图片流
     """
     new_text, at_uids, ctrl = await _parse_at(text)
@@ -178,14 +178,16 @@ async def _get_draw_data(
     return data
 
 
-async def upload_image(image: Picture, credential: Credential) -> dict:
+async def upload_image(image: Picture, credential: Credential, data: dict = None) -> dict:
     """
     上传动态图片
 
     Args:
-        image        (Picture)   : 图片流. 有格式要求.
-        credential   (Credential): 凭据
+        image (Picture)   : 图片流. 有格式要求.
 
+        credential (Credential): 凭据
+
+        data (dict): 自定义请求体
     Returns:
         dict: 调用 API 返回的结果
     """
@@ -195,16 +197,11 @@ async def upload_image(image: Picture, credential: Credential) -> dict:
     api = API["send"]["upload_img"]
     raw = image.content
 
-    data = {"biz": "new_dyn", "category": "daily"}
-
-    return_info = await request(
-        "POST",
-        url=api["url"],
-        data=data,
-        files={"file_up": raw},
-        credential=credential,
-    )
+    if data is None:
+        data = {"biz": "new_dyn", "category": "daily"}
 
+    files={"file_up": raw}
+    return_info = await Api(**api, credential=credential).update_data(**data).request(files=files)
     return return_info
 
 
@@ -257,10 +254,15 @@ class BuildDynmaic:
 
         Args:
             text            (str            , optional): 动态文字. Defaults to "".
+
             pics            (List[Picture]  , optional): 动态图片列表. Defaults to [].
+
             topic_id        (int            , optional): 动态话题 id. Defaults to -1.
+
             vote_id         (int            , optional): 动态中的投票的 id. 将放在整个动态的最后面. Defaults to -1.
+
             live_reserve_id (int            , optional): 直播预约 oid. 通过 `live.create_live_reserve` 获取. Defaults to -1.
+
             send_time       (datetime | None, optional): 发送时间. Defaults to None.
         """
         dyn = BuildDynmaic()
@@ -524,6 +526,7 @@ class BuildDynmaic:
 
         Args:
             up_choose_comment	(bool): 	精选评论flag
+
             close_comment	    (bool): 	关闭评论flag
         """
         if up_choose_comment:
@@ -569,6 +572,7 @@ async def send_dynamic(info: BuildDynmaic, credential: Credential):
 
     Args:
         info (BuildDynmaic): 动态内容
+
         credential (Credential): 凭据
 
     Returns:
@@ -601,7 +605,7 @@ async def send_dynamic(info: BuildDynmaic, credential: Credential):
             "publish_time": int(send_time.timestamp()),  # type: ignore
             "request": json.dumps(request_data, ensure_ascii=False),
         }
-        return await request("POST", api["url"], data=data, credential=credential)
+        return await Api(**api, credential=credential).update_data(**data).result
 
     if info.time != None:
         return await schedule(2 if len(info.pics) == 0 else 4)
@@ -626,14 +630,8 @@ async def send_dynamic(info: BuildDynmaic, credential: Credential):
         data["dyn_req"]["attach_card"]["common_card"] = info.get_attach_card()
     else:
         data["dyn_req"]["attach_card"] = None
-    send_result = await request(
-        "POST",
-        api["url"],
-        data=data,
-        credential=credential,
-        params={"csrf": credential.bili_jct},
-        json_body=True,
-    )
+    params = {"csrf": credential.bili_jct}
+    send_result = await Api(**api, credential=credential, json_body=True).update_data(**data).update_params(**params).result
     return send_result
 
 
@@ -653,7 +651,7 @@ async def get_schedules_list(credential: Credential) -> dict:
     credential.raise_for_no_sessdata()
 
     api = API["schedule"]["list"]
-    return await request("GET", api["url"], credential=credential)
+    return await Api(**api, credential=credential).result
 
 
 async def send_schedule_now(draft_id: int, credential: Credential) -> dict:
@@ -662,6 +660,7 @@ async def send_schedule_now(draft_id: int, credential: Credential) -> dict:
 
     Args:
         draft_id (int): 定时动态 ID
+
         credential  (Credential): 凭据
 
     Returns:
@@ -671,7 +670,7 @@ async def send_schedule_now(draft_id: int, credential: Credential) -> dict:
 
     api = API["schedule"]["publish_now"]
     data = {"draft_id": draft_id}
-    return await request("POST", api["url"], data=data, credential=credential)
+    return await Api(**api, credential=credential).update_data(**data).result
 
 
 async def delete_schedule(draft_id: int, credential: Credential) -> dict:
@@ -680,6 +679,7 @@ async def delete_schedule(draft_id: int, credential: Credential) -> dict:
 
     Args:
         draft_id (int): 定时动态 ID
+
         credential  (Credential): 凭据
 
     Returns:
@@ -689,7 +689,7 @@ async def delete_schedule(draft_id: int, credential: Credential) -> dict:
 
     api = API["schedule"]["delete"]
     data = {"draft_id": draft_id}
-    return await request("POST", api["url"], data=data, credential=credential)
+    return await Api(**api, credential=credential).update_data(**data).result
 
 
 class Dynamic:
@@ -728,9 +728,7 @@ class Dynamic:
             "timezone_offset": -480,
             "features": "itemOpusStyle",
         }
-        data = await request(
-            "GET", api["url"], params=params, credential=self.credential
-        )
+        data = await Api(**api, credential=self.credential).update_params(**params).result
         return data
 
     async def get_reposts(self, offset: str = "0") -> dict:
@@ -747,9 +745,7 @@ class Dynamic:
         params: dict[str, Any] = {"dynamic_id": self.__dynamic_id}
         if offset != "0":
             params["offset"] = offset
-        return await request(
-            "GET", api["url"], params=params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def get_likes(self, pn: int = 1, ps: int = 30) -> dict:
         """
@@ -757,6 +753,7 @@ class Dynamic:
 
         Args:
             pn (int, optional): 页码，defaults to 1
+
             ps (int, optional): 每页大小，defaults to 30
 
         Returns:
@@ -764,9 +761,7 @@ class Dynamic:
         """
         api = API["info"]["likes"]
         params = {"dynamic_id": self.__dynamic_id, "pn": pn, "ps": ps}
-        return await request(
-            "GET", api["url"], params=params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def set_like(self, status: bool = True) -> dict:
         """
@@ -791,7 +786,7 @@ class Dynamic:
             "up": 1 if status else 2,
             "uid": self_uid,
         }
-        return await request("POST", api["url"], data=data, credential=self.credential)
+        return await Api(**api, credential=self.credential).update_data(**data).result
 
     async def delete(self) -> dict:
         """
@@ -804,7 +799,7 @@ class Dynamic:
 
         api = API["operate"]["delete"]
         data = {"dynamic_id": self.__dynamic_id}
-        return await request("POST", api["url"], data=data, credential=self.credential)
+        return await Api(**api, credential=self.credential).update_data(**data).result
 
     async def repost(self, text: str = "转发动态") -> dict:
         """
@@ -821,7 +816,7 @@ class Dynamic:
         api = API["operate"]["repost"]
         data = await _get_text_data(text)
         data["dynamic_id"] = self.__dynamic_id
-        return await request("POST", api["url"], data=data, credential=self.credential)
+        return await Api(**api, credential=self.credential).update_data(**data).result
 
 
 async def get_new_dynamic_users(credential: Union[Credential, None] = None) -> dict:
@@ -837,7 +832,7 @@ async def get_new_dynamic_users(credential: Union[Credential, None] = None) -> d
     credential = credential if credential else Credential()
     credential.raise_for_no_sessdata()
     api = API["info"]["attention_new_dynamic"]
-    return await request("GET", api["url"], credential=credential)
+    return await Api(**api, credential=credential).result
 
 
 async def get_live_users(
@@ -848,6 +843,7 @@ async def get_live_users(
 
     Args:
         size       (int)       : 获取的数据数量. Defaults to 10.
+
         credential (Credential | None): 凭据类. Defaults to None.
 
     Returns:
@@ -857,7 +853,7 @@ async def get_live_users(
     credential.raise_for_no_sessdata()
     api = API["info"]["attention_live"]
     params = {"size": size}
-    return await request("GET", api["url"], params=params, credential=credential)
+    return await Api(**api, credential=credential).update_params(**params).result
 
 
 async def get_dynamic_page_UPs_info(credential: Credential) -> dict:
@@ -871,7 +867,7 @@ async def get_dynamic_page_UPs_info(credential: Credential) -> dict:
         dict: 调用 API 返回的结果
     """
     api = API["info"]["dynamic_page_UPs_info"]
-    return await request("GET", api["url"], credential=credential)
+    return await Api(**api, credential=credential).result
 
 
 async def get_dynamic_page_info(
@@ -885,15 +881,19 @@ async def get_dynamic_page_info(
     获取动态页动态信息
 
     获取全部动态或者相应类型需传入 _type
+
     获取指定 UP 主动态需传入 host_mid
 
     Args:
         credential (Credential): 凭据类.
-        _type      (DynamicType, optional): 动态类型. Defaults to DynamicType.ALL.
-        host_mid   (int, optional): 获取对应 UP 主动态的 mid. Defaults to None.
-        pn         (int, optional): 页码. Defaults to 1.
-        offset     (int, optional): 偏移值（下一页的第一个动态 ID，为该请求结果中的 offset 键对应的值），类似单向链表. Defaults to None.
 
+        _type      (DynamicType, optional): 动态类型. Defaults to DynamicType.ALL.
+
+        host_mid   (int, optional): 获取对应 UP 主动态的 mid. Defaults to None.
+
+        pn         (int, optional): 页码. Defaults to 1.
+
+        offset     (int, optional): 偏移值（下一页的第一个动态 ID，为该请求结果中的 offset 键对应的值），类似单向链表. Defaults to None.
 
     Returns:
         list[Dynamic]: 动态类列表
@@ -911,9 +911,7 @@ async def get_dynamic_page_info(
     elif host_mid:  # 指定 UP 主动态
         params["host_mid"] = host_mid
 
-    dynmaic_data = await request(
-        "GET", api["url"], credential=credential, params=params
-    )
+    dynmaic_data = await Api(**api, credential=credential).update_params(**params).result
     return [
         Dynamic(dynamic_id=int(dynamic["id_str"]), credential=credential)
         for dynamic in dynmaic_data["items"]
