@@ -5,14 +5,14 @@ bilibili_api.favorite_list
 """
 
 from enum import Enum
+from typing import List, Union, Optional
 
-from .video import Video
 from . import user
-from .utils.network_httpx import request
+from .video import Video
+from .utils.utils import join, get_api
+from .utils.credential import Credential
+from .utils.network_httpx import Api
 from .exceptions.ArgsException import ArgsException
-from .utils.Credential import Credential
-from .utils.utils import get_api, join
-from typing import List, Union
 
 API = get_api("favorite-list")
 
@@ -45,6 +45,18 @@ class FavoriteListType(Enum):
     CHEESE = "pugvfav"
 
 
+class SearchFavoriteListMode(Enum):
+    """
+    收藏夹搜索模式枚举
+
+    + ONLY : 仅当前收藏夹
+    + ALL  : 该用户所有收藏夹
+    """
+
+    ONLY = 0
+    ALL = 1
+
+
 class FavoriteList:
     """
     收藏夹类
@@ -62,7 +74,9 @@ class FavoriteList:
         """
         Args:
             type_      (FavoriteListType, optional): 收藏夹类型. Defaults to FavoriteListType.VIDEO.
+
             media_id   (int, optional)             : 收藏夹号（仅为视频收藏夹时提供）. Defaults to None.
+
             credential (Credential, optional)      : 凭据类. Defaults to Credential().
         """
         self.__type = type_
@@ -84,6 +98,20 @@ class FavoriteList:
     def get_favorite_list_type(self) -> FavoriteListType:
         return self.__type
 
+    async def get_info(self):
+        """
+        获取收藏夹信息。
+
+        Returns:
+            dict: 调用 API 返回的结果
+        """
+        assert self.__media_id != None, "视频收藏夹需要 media_id"
+
+        api = API["info"]["info"]
+        params = {"media_id": self.__media_id}
+
+        return await Api(**api, credential=self.credential).update_params(**params).result
+
     async def get_content_video(
         self,
         page: int = 1,
@@ -96,8 +124,11 @@ class FavoriteList:
 
         Args:
             page    (int, optional)                     : 页码. Defaults to 1.
+
             keyword (str | None, optional)              : 搜索关键词. Defaults to None.
+
             order   (FavoriteListContentOrder, optional): 排序方式. Defaults to FavoriteListContentOrder.MTIME.
+
             tid     (int, optional)                     : 分区 ID. Defaults to 0.
 
         Returns:
@@ -132,6 +163,20 @@ class FavoriteList:
         else:
             raise ArgsException("无法识别传入的类型")
 
+    async def get_content_ids_info(self) -> dict:
+        """
+        获取收藏夹所有内容的 ID。
+
+        Returns:
+            dict: 调用 API 返回的结果
+        """
+        assert self.__media_id != None, "视频收藏夹需要 media_id"
+
+        api = API["info"]["list_content_id_list"]
+        params = {"media_id": self.__media_id}
+
+        return await Api(**api, credential=self.credential).update_params(**params).result
+
 
 async def get_video_favorite_list(
     uid: int,
@@ -143,7 +188,9 @@ async def get_video_favorite_list(
 
     Args:
         uid        (int)                   : 用户 UID。
+
         video      (Video | None, optional): 视频类。若提供该参数则结果会附带该收藏夹是否存在该视频。Defaults to None.
+
         credential (Credential | None, optional)  : 凭据. Defaults to None.
 
     Returns:
@@ -155,7 +202,7 @@ async def get_video_favorite_list(
     if video is not None:
         params["rid"] = video.get_aid()
 
-    return await request("GET", url=api["url"], params=params, credential=credential)
+    return await Api(**api, credential=credential).update_params(**params).result
 
 
 async def get_video_favorite_list_content(
@@ -164,17 +211,27 @@ async def get_video_favorite_list_content(
     keyword: Union[str, None] = None,
     order: FavoriteListContentOrder = FavoriteListContentOrder.MTIME,
     tid: int = 0,
+    mode: SearchFavoriteListMode = SearchFavoriteListMode.ONLY,
     credential: Union[Credential, None] = None,
 ) -> dict:
     """
-    获取视频收藏夹列表内容。
+    获取视频收藏夹列表内容，也可用于搜索收藏夹内容。
+
+    mode 参数见 SearchFavoriteListMode 枚举。
 
     Args:
         media_id   (int)                               : 收藏夹 ID。
+
         page       (int, optional)                     : 页码. Defaults to 1.
+
         keyword    (str, optional)                     : 搜索关键词. Defaults to None.
+
         order      (FavoriteListContentOrder, optional): 排序方式. Defaults to FavoriteListContentOrder.MTIME.
+
         tid        (int, optional)                     : 分区 ID. Defaults to 0.
+
+        mode       (SearchFavoriteListMode, optional)  : 搜索模式，默认仅当前收藏夹.
+
         credential (Credential, optional)              : Credential. Defaults to None.
 
     Returns:
@@ -187,12 +244,13 @@ async def get_video_favorite_list_content(
         "ps": 20,
         "order": order.value,
         "tid": tid,
+        "type": mode.value,
     }
 
     if keyword is not None:
         params["keyword"] = keyword
 
-    return await request("GET", api["url"], params=params, credential=credential)
+    return await Api(**api, credential=credential).update_params(**params).result
 
 
 async def get_topic_favorite_list(
@@ -203,6 +261,7 @@ async def get_topic_favorite_list(
 
     Args:
         page       (int, optional)              : 页码. Defaults to 1.
+
         credential (Credential | None, optional): Credential
 
     Returns:
@@ -216,7 +275,7 @@ async def get_topic_favorite_list(
     api = API["info"]["list_topics"]
     params = {"page_num": page, "page_size": 16}
 
-    return await request("GET", api["url"], params=params, credential=credential)
+    return await Api(**api, credential=credential).update_params(**params).result
 
 
 async def get_article_favorite_list(
@@ -227,6 +286,7 @@ async def get_article_favorite_list(
 
     Args:
         page       (int, optional)              : 页码. Defaults to 1.
+
         credential (Credential | None, optional): Credential. Defaults to None.
 
     Returns:
@@ -240,7 +300,7 @@ async def get_article_favorite_list(
     api = API["info"]["list_articles"]
     params = {"pn": page, "ps": 16}
 
-    return await request("GET", api["url"], params=params, credential=credential)
+    return await Api(**api, credential=credential).update_params(**params).result
 
 
 async def get_album_favorite_list(
@@ -251,6 +311,7 @@ async def get_album_favorite_list(
 
     Args:
         page       (int, optional)              : 页码. Defaults to 1.
+
         credential (Credential | None, optional): Credential. Defaults to None.
 
     Returns:
@@ -264,7 +325,7 @@ async def get_album_favorite_list(
     api = API["info"]["list_albums"]
     params = {"page": page, "pagesize": 30, "biz_type": 2}
 
-    return await request("GET", api["url"], params=params, credential=credential)
+    return await Api(**api, credential=credential).update_params(**params).result
 
 
 async def get_course_favorite_list(
@@ -275,6 +336,7 @@ async def get_course_favorite_list(
 
     Args:
         page       (int, optional)       : 页码. Defaults to 1.
+
         credential (Credential | None, optional): Credential. Defaults to None.
 
     Returns:
@@ -289,7 +351,7 @@ async def get_course_favorite_list(
     self_info = await user.get_self_info(credential)
     params = {"pn": page, "ps": 10, "mid": self_info["mid"]}
 
-    return await request("GET", api["url"], params=params, credential=credential)
+    return await Api(**api, credential=credential).update_params(**params).result
 
 
 async def get_note_favorite_list(
@@ -300,6 +362,7 @@ async def get_note_favorite_list(
 
     Args:
         page       (int, optional)       : 页码. Defaults to 1.
+
         credential (Credential | None, optional): Credential. Defaults to None.
 
     Returns:
@@ -313,7 +376,7 @@ async def get_note_favorite_list(
     api = API["info"]["list_notes"]
     params = {"pn": page, "ps": 16}
 
-    return await request("GET", api["url"], params=params, credential=credential)
+    return await Api(**api, credential=credential).update_params(**params).result
 
 
 async def create_video_favorite_list(
@@ -327,8 +390,11 @@ async def create_video_favorite_list(
 
     Args:
         title        (str)                 : 收藏夹名。
+
         introduction (str, optional)       : 收藏夹简介. Defaults to ''.
+
         private      (bool, optional)      : 是否为私有. Defaults to False.
+
         credential   (Credential, optional): 凭据. Defaults to None.
 
     Returns:
@@ -348,7 +414,7 @@ async def create_video_favorite_list(
         "cover": "",
     }
 
-    return await request("POST", api["url"], data=data, credential=credential)
+    return await Api(**api, credential=credential).update_data(**data).result
 
 
 async def modify_video_favorite_list(
@@ -363,9 +429,13 @@ async def modify_video_favorite_list(
 
     Args:
         media_id     (int)                 : 收藏夹 ID.
+
         title        (str)                 : 收藏夹名。
+
         introduction (str, optional)       : 收藏夹简介. Defaults to ''.
+
         private      (bool, optional)      : 是否为私有. Defaults to False.
+
         credential   (Credential, optional): Credential. Defaults to None.
 
     Returns:
@@ -387,7 +457,7 @@ async def modify_video_favorite_list(
         "media_id": media_id,
     }
 
-    return await request("POST", api["url"], data=data, credential=credential)
+    return await Api(**api, credential=credential).update_data(**data).result
 
 
 async def delete_video_favorite_list(
@@ -398,6 +468,7 @@ async def delete_video_favorite_list(
 
     Args:
         media_ids  (List[int]) : 收藏夹 ID 列表。
+
         credential (Credential): Credential.
 
     Returns:
@@ -410,7 +481,7 @@ async def delete_video_favorite_list(
     data = {"media_ids": join(",", media_ids)}
     api = API["operate"]["delete"]
 
-    return await request("POST", api["url"], data=data, credential=credential)
+    return await Api(**api, credential=credential).update_data(**data).result
 
 
 async def copy_video_favorite_list_content(
@@ -421,8 +492,11 @@ async def copy_video_favorite_list_content(
 
     Args:
         media_id_from (int)       : 要复制的源收藏夹 ID。
+
         media_id_to   (int)       : 目标收藏夹 ID。
+
         aids          (List[int]) : 被复制的视频 ID 列表。
+
         credential    (Credential): 凭据
 
     Returns:
@@ -441,7 +515,7 @@ async def copy_video_favorite_list_content(
         "resources": ",".join(map(lambda x: f"{str(x)}:2", aids)),
     }
 
-    return await request("POST", api["url"], data=data, credential=credential)
+    return await Api(**api, credential=credential).update_data(**data).result
 
 
 async def move_video_favorite_list_content(
@@ -452,8 +526,11 @@ async def move_video_favorite_list_content(
 
     Args:
         media_id_from (int)       : 要移动的源收藏夹 ID。
+
         media_id_to   (int)       : 目标收藏夹 ID。
+
         aids          (List[int]) : 被移动的视频 ID 列表。
+
         credential    (Credential): 凭据
 
     Returns:
@@ -469,7 +546,7 @@ async def move_video_favorite_list_content(
         "resources": ",".join(map(lambda x: f"{str(x)}:2", aids)),
     }
 
-    return await request("POST", api["url"], data=data, credential=credential)
+    return await Api(**api, credential=credential).update_data(**data).result
 
 
 async def delete_video_favorite_list_content(
@@ -480,7 +557,9 @@ async def delete_video_favorite_list_content(
 
     Args:
         media_id   (int)       : 收藏夹 ID。
+
         aids       (List[int]) : 被删除的视频 ID 列表。
+
         credential (Credential): 凭据
 
     Returns:
@@ -495,7 +574,7 @@ async def delete_video_favorite_list_content(
         "resources": ",".join(map(lambda x: f"{str(x)}:2", aids)),
     }
 
-    return await request("POST", api["url"], data=data, credential=credential)
+    return await Api(**api, credential=credential).update_data(**data).result
 
 
 async def clean_video_favorite_list_content(
@@ -506,6 +585,7 @@ async def clean_video_favorite_list_content(
 
     Args:
         media_id   (int)       : 收藏夹 ID
+
         credential (Credential): 凭据
 
     Returns:
@@ -517,4 +597,27 @@ async def clean_video_favorite_list_content(
 
     data = {"media_id": media_id}
 
-    return await request("POST", api["url"], data=data, credential=credential)
+    return await Api(**api, credential=credential).update_data(**data).result
+
+
+async def get_favorite_collected(
+    uid: int,
+    pn: int = 1,
+    ps: int = 20,
+    credential: Union[Credential, None] = None,
+) -> dict:
+    """
+    获取收藏合集列表
+
+    Args:
+        uid        (int)                               : 用户 UID。
+
+        pn         (int, optional)                     : 页码. Defaults to 1.
+
+        ps         (int, optional)                     : 每页数据大小. Defaults to 20.
+
+        credential (Credential | None, optional)       : Credential. Defaults to None.
+    """
+    api = API["info"]["collected"]
+    params = {"up_mid": uid, "platform": "web", "pn": pn, "ps": ps}
+    return await Api(**api, credential=credential).update_params(**params).result
