@@ -3,25 +3,25 @@ bilibili_api.live
 
 直播相关
 """
-import base64
-import time
-from enum import Enum
-import logging
 import json
+import time
+import base64
 import struct
 import asyncio
+import logging
+from enum import Enum
 from typing import Any, List, Union
-import aiohttp
-import brotli
 
+import brotli
+import aiohttp
 from aiohttp.client_ws import ClientWebSocketResponse
 
-from .utils.Credential import Credential
-from .utils.network_httpx import request
-from .utils.network import get_session
 from .utils.utils import get_api
-from .utils.Danmaku import Danmaku
+from .utils.danmaku import Danmaku
+from .utils.network import get_session
 from .utils.AsyncEvent import AsyncEvent
+from .utils.credential import Credential
+from .utils.network_httpx import Api
 from .exceptions.LiveException import LiveException
 
 API = get_api("live")
@@ -103,6 +103,7 @@ class LiveRoom:
 
     AttributesL
         credential      (Credential): 凭据类
+
         room_display_id (int)       : 房间展示 id
     """
 
@@ -112,6 +113,7 @@ class LiveRoom:
         """
         Args:
             room_display_id (int)                 : 房间展示 ID（即 URL 中的 ID）
+
             credential      (Credential, optional): 凭据. Defaults to None.
         """
         self.room_display_id = room_display_id
@@ -139,9 +141,7 @@ class LiveRoom:
             "room_id": self.room_display_id,
             "platform": "pc",
         }
-        resp = await request(
-            api["method"], api["url"], params=params, credential=self.credential
-        )
+        resp = await Api(**api, credential=self.credential).update_params(**params).result
         return resp
 
     async def stop(self) -> dict:
@@ -155,9 +155,7 @@ class LiveRoom:
         params = {
             "room_id": self.room_display_id,
         }
-        resp = await request(
-            api["method"], api["url"], params=params, credential=self.credential
-        )
+        resp = await Api(**api, credential=self.credential).update_params(**params).result
         return resp
 
     async def get_room_play_info(self) -> dict:
@@ -171,9 +169,7 @@ class LiveRoom:
         params = {
             "room_id": self.room_display_id,
         }
-        resp = await request(
-            api["method"], api["url"], params=params, credential=self.credential
-        )
+        resp = await Api(**api, credential=self.credential).update_params(**params).result
 
         # 缓存真实房间 ID
         self.__ruid = resp["uid"]
@@ -203,9 +199,7 @@ class LiveRoom:
         """
         api = API["info"]["chat_conf"]
         params = {"room_id": self.room_display_id}
-        return await request(
-            api["method"], api["url"], params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def get_room_info(self) -> dict:
         """
@@ -216,9 +210,7 @@ class LiveRoom:
         """
         api = API["info"]["room_info"]
         params = {"room_id": self.room_display_id}
-        return await request(
-            api["method"], api["url"], params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def get_fan_model(
         self,
@@ -235,7 +227,9 @@ class LiveRoom:
 
         Args:
             roomId    (int, optional)       : 指定房间，查询是否拥有此房间的粉丝牌
+
             target_id (int | None, optional): 指定返回一个主播的粉丝牌，留空就不返回
+
             page_num  (int | None, optional): 粉丝牌列表，默认 1
 
         Returns:
@@ -252,9 +246,7 @@ class LiveRoom:
             params["roomId"] = roomId
         if target_id:
             params["target_id"] = target_id
-        return await request(
-            api["method"], api["url"], params=params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def get_user_info_in_room(self) -> dict:
         """
@@ -267,9 +259,7 @@ class LiveRoom:
 
         api = API["info"]["user_info_in_room"]
         params = {"room_id": self.room_display_id}
-        return await request(
-            api["method"], api["url"], params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def get_dahanghai(self, page: int = 1) -> dict:
         """
@@ -288,9 +278,7 @@ class LiveRoom:
             "page_size": 30,
             "page": page,
         }
-        return await request(
-            api["method"], api["url"], params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def get_gaonengbang(self, page: int = 1) -> dict:
         """
@@ -309,9 +297,7 @@ class LiveRoom:
             "pageSize": 50,
             "page": page,
         }
-        return await request(
-            api["method"], api["url"], params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def get_seven_rank(self) -> dict:
         """
@@ -325,9 +311,7 @@ class LiveRoom:
             "roomid": self.room_display_id,
             "ruid": await self.__get_ruid(),
         }
-        return await request(
-            api["method"], api["url"], params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def get_fans_medal_rank(self) -> dict:
         """
@@ -338,9 +322,7 @@ class LiveRoom:
         """
         api = API["info"]["fans_medal_rank"]
         params = {"roomid": self.room_display_id, "ruid": await self.__get_ruid()}
-        return await request(
-            api["method"], api["url"], params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def get_black_list(self) -> dict:
         """
@@ -352,9 +334,7 @@ class LiveRoom:
         api = API["info"]["black_list"]
         params = {"room_id": self.room_display_id, "ps": 1}
 
-        return await request(
-            api["method"], api["url"], params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def get_room_play_url(
         self, screen_resolution: ScreenResolution = ScreenResolution.ORIGINAL
@@ -376,9 +356,7 @@ class LiveRoom:
             "https_url_req": "1",
             "ptype": "16",
         }
-        return await request(
-            api["method"], api["url"], params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def get_room_play_info_v2(
         self,
@@ -392,8 +370,11 @@ class LiveRoom:
 
         Args:
             live_protocol (LiveProtocol, optional)    : 直播源流协议. Defaults to LiveProtocol.DEFAULT.
+
             live_format   (LiveFormat, optional)      : 直播源容器格式. Defaults to LiveFormat.DEFAULT.
+
             live_codec    (LiveCodec, optional)       : 直播源视频编码. Defaults to LiveCodec.DEFAULT.
+
             live_qn       (ScreenResolution, optional): 直播源清晰度. Defaults to ScreenResolution.ORIGINAL.
 
         Returns:
@@ -409,9 +390,7 @@ class LiveRoom:
             "codec": live_codec.value,
             "qn": live_qn.value,
         }
-        return await request(
-            api["method"], api["url"], params=params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def ban_user(self, uid: int) -> dict:
         """
@@ -432,9 +411,7 @@ class LiveRoom:
             "mobile_app": "web",
             "visit_id": "",
         }
-        return await request(
-            api["method"], api["url"], data=data, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_data(**data).result
 
     async def unban_user(self, block_id: int) -> dict:
         """
@@ -453,9 +430,7 @@ class LiveRoom:
             "id": block_id,
             "visit_id": "",
         }
-        return await request(
-            api["method"], api["url"], data=data, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_data(**data).result
 
     async def send_danmaku(self, danmaku: Danmaku) -> dict:
         """
@@ -482,9 +457,7 @@ class LiveRoom:
             "fontsize": danmaku.font_size,
         }
 
-        return await request(
-            api["method"], api["url"], data=data, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_data(**data).result
 
     async def sign_up_dahanghai(self, task_id: int = 1447) -> dict:
         """
@@ -504,9 +477,7 @@ class LiveRoom:
             "task_id": task_id,
             "uid": await self.__get_ruid(),
         }
-        return await request(
-            api["method"], api["url"], data=data, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_data(**data).result
 
     async def send_gift_from_bag(
         self,
@@ -522,10 +493,15 @@ class LiveRoom:
 
         Args:
             uid (int)                       : 赠送用户的 UID
+
             bag_id (int)                    : 礼物背包 ID
+
             gift_id (int)                   : 礼物 ID
+
             gift_num (int)                  : 礼物数量
+
             storm_beat_id (int, optional)   : 未知， Defaults to 0
+
             price (int, optional)           : 礼物单价，Defaults to 0
 
         Returns:
@@ -548,9 +524,7 @@ class LiveRoom:
             "biz_id": self.room_display_id,
             "ruid": await self.__get_ruid(),
         }
-        return await request(
-            api["method"], api["url"], data=data, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_data(**data).result
 
     async def receive_reward(self, receive_type: int = 2) -> dict:
         """
@@ -569,9 +543,7 @@ class LiveRoom:
             "ruid": await self.__get_ruid(),
             "receive_type": receive_type,
         }
-        return await request(
-            api["method"], api["url"], data=data, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_data(**data).result
 
     async def get_general_info(self, act_id: int = 100061) -> dict:
         """
@@ -591,9 +563,7 @@ class LiveRoom:
             "roomId": self.room_display_id,
             "uid": await self.__get_ruid(),
         }
-        return await request(
-            api["method"], api["url"], params=params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def get_gift_common(self) -> dict:
         """
@@ -606,12 +576,10 @@ class LiveRoom:
         params_room_info = {
             "room_id": self.room_display_id,
         }
-        res_room_info = await request(
-            api_room_info["method"],
-            api_room_info["url"],
-            params=params_room_info,
-            credential=self.credential,
-        )
+        res_room_info = await Api(
+            **api_room_info,
+            credential=self.credential
+            ).update_params(**params_room_info).result
         area_id, area_parent_id = (
             res_room_info["room_info"]["area_id"],
             res_room_info["room_info"]["parent_area_id"],
@@ -625,9 +593,7 @@ class LiveRoom:
             "platform": "pc",
             "source": "live",
         }
-        return await request(
-            api["method"], api["url"], params=params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def get_gift_special(self, tab_id: int) -> dict:
         """
@@ -643,12 +609,10 @@ class LiveRoom:
         params_room_info = {
             "room_id": self.room_display_id,
         }
-        res_room_info = await request(
-            api_room_info["method"],
-            api_room_info["url"],
-            params=params_room_info,
-            credential=self.credential,
-        )
+        res_room_info = await Api(
+            **api_room_info,
+            credential=self.credential
+            ).update_params(**params_room_info).result
         area_id, area_parent_id = (
             res_room_info["room_info"]["area_id"],
             res_room_info["room_info"]["parent_area_id"],
@@ -665,9 +629,7 @@ class LiveRoom:
             "platform": "pc",
             "build": 1,
         }
-        return await request(
-            api["method"], api["url"], params=params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def send_gift_gold(
         self, uid: int, gift_id: int, gift_num: int, price: int, storm_beat_id: int = 0
@@ -677,9 +639,13 @@ class LiveRoom:
 
         Args:
             uid           (int)          : 赠送用户的 UID
+
             gift_id       (int)          : 礼物 ID (可以通过 get_gift_common 或 get_gift_special 或 get_gift_config 获取)
+
             gift_num      (int)          : 赠送礼物数量
+
             price         (int)          : 礼物单价
+
             storm_beat_id (int, Optional): 未知，Defaults to 0
 
         Returns:
@@ -705,9 +671,7 @@ class LiveRoom:
             "rnd": int(time.time()),
             "visit_id": "",
         }
-        return await request(
-            api["method"], api["url"], data=data, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_data(**data).result
 
     async def send_gift_silver(
         self,
@@ -722,9 +686,13 @@ class LiveRoom:
 
         Args:
             uid           (int)          : 赠送用户的 UID
+
             gift_id       (int)          : 礼物 ID (可以通过 get_gift_common 或 get_gift_special 或 get_gift_config 获取)
+
             gift_num      (int)          : 赠送礼物数量
+
             price         (int)          : 礼物单价
+
             storm_beat_id (int, Optional): 未知, Defaults to 0
 
         Returns:
@@ -750,9 +718,7 @@ class LiveRoom:
             "rnd": int(time.time()),
             "visit_id": "",
         }
-        return await request(
-            api["method"], api["url"], data=data, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_data(**data).result
 
 
 class LiveDanmaku(AsyncEvent):
@@ -900,7 +866,9 @@ class LiveDanmaku(AsyncEvent):
         self.logger.info(f"准备连接直播间 {self.room_display_id}")
         # 获取真实房间号
         self.logger.debug("正在获取真实房间号")
-        self.__room_real_id = (await room.get_room_play_info())["room_id"]
+        info = await room.get_room_play_info()
+        self.__room__uid = info["uid"]
+        self.__room_real_id = info["room_id"]
         self.logger.debug(f"获取成功，真实房间号：{self.__room_real_id}")
 
         # 获取直播服务器配置
@@ -1044,9 +1012,10 @@ class LiveDanmaku(AsyncEvent):
 
     async def __send_verify_data(self, ws: ClientWebSocketResponse, token: str) -> None:
         verifyData = {
-            "uid": 0,
+            "uid": self.__room__uid,
             "roomid": self.__room_real_id,
             "protover": 3,
+            "buvid": self.credential.buvid3,
             "platform": "web",
             "type": 2,
             "key": token,
@@ -1074,9 +1043,7 @@ class LiveDanmaku(AsyncEvent):
                     base64.b64encode(f"60|{self.room_display_id}|1|0".encode("utf-8")),
                     "utf-8",
                 )
-                await request(
-                    "GET", heartbeat_url, params={"hb": hb, "pf": "web"}, json_body=True
-                )
+                await Api(method="GET", url=heartbeat_url, json_body=True).update_params(**{"hb": hb, "pf": "web"}).result
             elif self.__heartbeat_timer <= -30:
                 # 视为已异常断开连接，发布 TIMEOUT 事件
                 self.dispatch("TIMEOUT")
@@ -1175,7 +1142,7 @@ async def get_self_info(credential: Credential) -> dict:
     credential.raise_for_no_sessdata()
 
     api = API["info"]["user_info"]
-    return await request(api["method"], api["url"], credential=credential)
+    return await Api(**api, credential=credential).result
 
 
 async def get_self_live_info(credential: Credential) -> dict:
@@ -1189,7 +1156,7 @@ async def get_self_live_info(credential: Credential) -> dict:
     credential.raise_for_no_sessdata()
 
     api = API["info"]["live_info"]
-    return await request(api["method"], api["url"], credential=credential)
+    return await Api(**api, credential=credential).result
 
 
 async def get_self_dahanghai_info(
@@ -1200,6 +1167,7 @@ async def get_self_dahanghai_info(
 
     Args:
         page      (int, optional): 页数. Defaults to 1.
+
         page_size (int, optional): 每页数量. Defaults to 10.
 
     总页数取得方法:
@@ -1221,9 +1189,7 @@ async def get_self_dahanghai_info(
 
     api = API["info"]["user_guards"]
     params = {"page": page, "page_size": page_size}
-    return await request(
-        api["method"], api["url"], params=params, credential=credential
-    )
+    return await Api(**api, credential=credential).update_params(**params).result
 
 
 async def get_self_bag(credential: Credential) -> dict:
@@ -1237,7 +1203,7 @@ async def get_self_bag(credential: Credential) -> dict:
     credential.raise_for_no_sessdata()
 
     api = API["info"]["bag_list"]
-    return await request(api["method"], api["url"], credential=credential)
+    return await Api(**api, credential=credential).result
 
 
 async def get_gift_config(
@@ -1247,7 +1213,9 @@ async def get_gift_config(
 ):
     """
     获取所有礼物的信息，包括礼物 id、名称、价格、等级等。
+
     同时填了 room_id、area_id、area_parent_id，则返回一个较小的 json，只包含该房间、该子区域、父区域的礼物。
+
     但即使限定了三个条件，仍然会返回约 1.5w 行的 json。不加限定则是 2.8w 行。
 
     Args:
@@ -1266,7 +1234,7 @@ async def get_gift_config(
         "area_id": area_id if area_id is not None else "",
         "area_parent_id": area_parent_id if area_parent_id is not None else "",
     }
-    return await request(api["method"], api["url"], params=params)
+    return await Api(**api).update_params(**params).result
 
 
 async def get_area_info() -> dict:
@@ -1277,7 +1245,7 @@ async def get_area_info() -> dict:
         dict: 调用 API 返回的结果
     """
     api = API["info"]["area_info"]
-    return await request(api["method"], api["url"])
+    return await Api(**api).result
 
 
 async def get_live_followers_info(
@@ -1299,9 +1267,7 @@ async def get_live_followers_info(
 
     api = API["info"]["followers_live_info"]
     params = {"need_recommend": int(need_recommend), "filterRule": 0}
-    return await request(
-        api["method"], api["url"], params=params, credential=credential
-    )
+    return await Api(**api, credential=credential).update_params(**params).result
 
 
 async def get_unlive_followers_info(
@@ -1312,6 +1278,7 @@ async def get_unlive_followers_info(
 
     Args:
         page      (int, optional): 页码, Defaults to 1.
+
         page_size (int, optional): 每页数量 Defaults to 30.
 
     Returns:
@@ -1327,9 +1294,7 @@ async def get_unlive_followers_info(
         "page": page,
         "pagesize": page_size,
     }
-    return await request(
-        api["method"], api["url"], params=params, credential=credential
-    )
+    return await Api(**api, credential=credential).update_params(**params).result
 
 
 async def create_live_reserve(
@@ -1340,6 +1305,7 @@ async def create_live_reserve(
 
     Args:
         title (str)         : 直播间标题
+
         start_time (int)    : 开播时间戳
 
     Returns:
@@ -1355,4 +1321,4 @@ async def create_live_reserve(
         "stime": None,
         "from": 1,
     }
-    return await request("POST", api["url"], data=data, credential=credential)
+    return await Api(**api, credential=credential).update_data(**data).result
