@@ -4,17 +4,19 @@ bilibili_api.login_func
 登录功能相关
 """
 
+import enum
+import json
+import uuid
 import threading
 from typing import Tuple, Union
-from . import login
-from .utils.Credential import Credential
-from .utils.utils import get_api
-from .utils.Picture import Picture
-import json
+
 import requests
-import uuid
+
+from . import login
+from .utils.utils import get_api
 from .exceptions import LoginError
-import enum
+from .utils.picture import Picture
+from .utils.credential import Credential
 
 API = get_api("login")
 
@@ -40,8 +42,9 @@ def get_qrcode() -> Tuple[Picture, str]:
     Returns:
         Tuple[dir, str]: 第一项是二维码图片地址（本地缓存）和登录密钥。登录密钥需要保存。
     """
-    img = login.update_qrcode()
-    login_key = login.login_key
+    login_data = login.update_qrcode_data()
+    login_key = login_data["qrcode_key"]
+    img = login.make_qrcode(login_data["url"])
     return (Picture.from_file(img), login_key)
 
 
@@ -56,22 +59,22 @@ def check_qrcode_events(login_key) -> Tuple[QrCodeLoginEvents, Union[str, Creden
         Tuple[QrCodeLoginEvents, str|Credential]: 状态(第一项）和信息（第二项）（如果成功登录信息为凭据类）
     """
     events_api = API["qrcode"]["get_events"]
-    data = {"oauthKey": login_key}
+    params = {"qrcode_key": login_key}
     events = json.loads(
-        requests.post(
+        requests.get(
             events_api["url"],
-            data=data,
+            params=params,
             cookies={"buvid3": str(uuid.uuid1()), "Domain": ".bilibili.com"},
         ).text
     )
     if "code" in events.keys() and events["code"] == -412:
         raise LoginError(events["message"])
-    if events["data"] == -4:
+    if events["data"]["code"] == 86101:
         return QrCodeLoginEvents.SCAN, events["message"]
-    elif events["data"] == -5:
+    elif events["data"]["code"] == 86090:
         return QrCodeLoginEvents.CONF, events["message"]
-    elif isinstance(events["data"], dict):
-        url = events["data"]["url"]
+    elif events["data"]["code"] == 0:
+        url: str = events["data"]["url"]
         cookies_list = url.split("?")[1].split("&")
         sessdata = ""
         bili_jct = ""
@@ -106,7 +109,7 @@ def start_geetest_server() -> "ServerThreadModel":
     print(start_geetest_server().url)
     ```
     """
-    return login.start_server() # type: ignore
+    return login.start_server()  # type: ignore
 
 
 def close_geetest_server() -> None:
@@ -149,7 +152,7 @@ def safecenter_start_geetest_server() -> "ServerThreadModel":
     print(start_geetest_server().url)
     ```
     """
-    return login.safecenter_start_server() # type: ignore
+    return login.safecenter_start_server()  # type: ignore
 
 
 def safecenter_close_geetest_server() -> None:
@@ -183,7 +186,11 @@ class ServerThreadModel(threading.Thread):
     """
     A simple model for bilibili_api.utils.captcha._start_server.ServerThread.
     """
+
     url: str
-    def __init__(self, *args, **kwargs): ...
+
+    def __init__(self, *args, **kwargs):
+        ...
+
     def stop(self):
         """Stop the server and this thread nicely"""
