@@ -6,33 +6,36 @@ bilibili_api.video
 注意，同时存在 page_index 和 cid 的参数，两者至少提供一个。
 """
 
-from enum import Enum
 import re
-import datetime
-import asyncio
-import logging
 import json
 import struct
-import aiohttp
-import httpx
-from typing import Any, List, Union
-from functools import cmp_to_key
-
-from .exceptions import ResponseException
-from .exceptions import NetworkException
-from .exceptions import ArgsException, DanmakuClosedException
-
-from .utils.Credential import Credential
-from .utils.aid_bvid_transformer import aid2bvid, bvid2aid
-from .utils.utils import get_api
-from .utils.network_httpx import request, get_session
-from .utils.network import get_session as get_session_aiohttp
-from .utils.Danmaku import Danmaku, SpecialDanmaku
-from .utils.BytesReader import BytesReader
-from .utils.AsyncEvent import AsyncEvent
-from dataclasses import dataclass
-from . import settings
+import asyncio
+import logging
+import datetime
+from enum import Enum
 from inspect import isfunction
+from functools import cmp_to_key
+from dataclasses import dataclass
+from typing import Any, List, Union
+
+import httpx
+import aiohttp
+
+from . import settings
+from .utils.aid_bvid_transformer import bvid2aid, aid2bvid
+from .utils.utils import get_api
+from .utils.AsyncEvent import AsyncEvent
+from .utils.credential import Credential
+from .utils.BytesReader import BytesReader
+from .utils.danmaku import Danmaku, SpecialDanmaku
+from .utils.network_httpx import Api, get_session
+from .utils.network import get_session as get_session_aiohttp
+from .exceptions import (
+    ArgsException,
+    NetworkException,
+    ResponseException,
+    DanmakuClosedException,
+)
 
 API = get_api("video")
 
@@ -46,7 +49,7 @@ async def get_cid_info(cid: int):
     """
     api = API["info"]["cid_info"]
     params = {"cid": cid}
-    return await request("GET", api["url"], params=params)
+    return await Api(**api).update_params(**params).result
 
 
 class DanmakuOperatorType(Enum):
@@ -139,7 +142,9 @@ class Video:
         """
         Args:
             bvid       (str | None, optional)       : BV 号. bvid 和 aid 必须提供其中之一。
+
             aid        (int | None, optional)       : AV 号. bvid 和 aid 必须提供其中之一。
+
             credential (Credential | None, optional): Credential 类. Defaults to None.
         """
         # ID 检查
@@ -210,9 +215,7 @@ class Video:
         """
         api = API["info"]["detail"]
         params = {"bvid": self.get_bvid(), "aid": self.get_aid()}
-        resp = await request(
-            "GET", api["url"], params=params, credential=self.credential
-        )
+        resp = await Api(**api, credential=self.credential).update_params(**params).result
         # 存入 self.__info 中以备后续调用
         self.__info = resp
         return resp
@@ -235,31 +238,32 @@ class Video:
         Returns:
             dict: 调用 API 返回的结果。
         """
-        url = API["info"]["stat"]["url"]
+        api = API["info"]["stat"]
         params = {"bvid": self.get_bvid(), "aid": self.get_aid()}
-        return await request("GET", url, params=params, credential=self.credential)
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def get_tags(
         self, page_index: Union[int, None] = 0, cid: Union[int, None] = None
-    ) -> dict:
+    ) -> List[dict]:
         """
         获取视频标签。
 
         Args:
             page_index (int | None): 分 P 序号. Defaults to 0.
+
             cid        (int | None): 分 P 编码. Defaults to None.
 
         Returns:
-            dict: 调用 API 返回的结果。
+            List[dict]: 调用 API 返回的结果。
         """
         if cid == None:
             if page_index == None:
                 raise ArgsException("page_index 和 cid 至少提供一个。")
 
             cid = await self.get_cid(page_index=page_index)
-        url = API["info"]["tags"]["url"]
+        api = API["info"]["tags"]
         params = {"bvid": self.get_bvid(), "aid": self.get_aid(), "cid": cid}
-        return await request("GET", url, params=params, credential=self.credential)
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def get_chargers(self) -> dict:
         """
@@ -270,20 +274,20 @@ class Video:
         """
         info = await self.__get_info_cached()
         mid = info["owner"]["mid"]
-        url = API["info"]["chargers"]["url"]
+        api = API["info"]["chargers"]
         params = {"aid": self.get_aid(), "bvid": self.get_bvid(), "mid": mid}
-        return await request("GET", url, params=params, credential=self.credential)
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
-    async def get_pages(self) -> dict:
+    async def get_pages(self) -> List[dict]:
         """
         获取分 P 信息。
 
         Returns:
             dict: 调用 API 返回的结果。
         """
-        url = API["info"]["pages"]["url"]
+        api = API["info"]["pages"]
         params = {"aid": self.get_aid(), "bvid": self.get_bvid()}
-        return await request("GET", url, params=params, credential=self.credential)
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def __get_page_id_by_index(self, page_index: int) -> int:
         """
@@ -319,7 +323,9 @@ class Video:
 
         Args:
             cid(int): 分 P CID(可选)
+
             json_index(bool): json 数组截取时间表 True 为需要，False 不需要
+
             pvideo(bool): 是否只获取预览
 
         Returns:
@@ -327,15 +333,15 @@ class Video:
         """
         params: dict[str, Any] = {"aid": self.get_aid()}
         if pvideo:
-            url = API["info"]["video_snapshot_pvideo"]["url"]
+            api = API["info"]["video_snapshot_pvideo"]
         else:
             params["bvid"] = self.get_bvid()
             if json_index:
                 params["index"] = 1
             if cid:
                 params["cid"] = cid
-            url = API["info"]["video_snapshot"]["url"]
-        return await request("GET", url, params=params)
+            api = API["info"]["video_snapshot"]
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def get_cid(self, page_index: int) -> int:
         """
@@ -364,7 +370,9 @@ class Video:
 
         Args:
             page_index (int | None, optional) : 分 P 号，从 0 开始。Defaults to None
+
             cid        (int | None, optional) : 分 P 的 ID。Defaults to None
+
             html5      (bool, optional): 是否以 html5 平台访问，这样子能直接在网页中播放，但是链接少。
 
         Returns:
@@ -376,7 +384,7 @@ class Video:
 
             cid = await self.__get_page_id_by_index(page_index)
 
-        url = API["info"]["playurl"]["url"]
+        api = API["info"]["playurl"]
         if html5:
             params = {
                 "avid": self.get_aid(),
@@ -396,7 +404,7 @@ class Video:
                 "fnval": 4048,
                 "fourk": 1,
             }
-        result = await request("GET", url, params=params, credential=self.credential)
+        result = await Api(**api, credential=self.credential).update_params(**params).result
         result.update({"is_html5": True} if html5 else {})
         return result
 
@@ -407,9 +415,9 @@ class Video:
         Returns:
             dict: 调用 API 返回的结果。
         """
-        url = API["info"]["related"]["url"]
+        api = API["info"]["related"]
         params = {"aid": self.get_aid(), "bvid": self.get_bvid()}
-        return await request("GET", url, params=params, credential=self.credential)
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def has_liked(self) -> bool:
         """
@@ -420,9 +428,9 @@ class Video:
         """
         self.credential.raise_for_no_sessdata()
 
-        url = API["info"]["has_liked"]["url"]
+        api = API["info"]["has_liked"]
         params = {"bvid": self.get_bvid(), "aid": self.get_aid()}
-        return await request("GET", url, params=params, credential=self.credential) == 1
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def get_pay_coins(self) -> int:
         """
@@ -433,9 +441,9 @@ class Video:
         """
         self.credential.raise_for_no_sessdata()
 
-        url = API["info"]["get_pay_coins"]["url"]
+        api = API["info"]["get_pay_coins"]
         params = {"bvid": self.get_bvid(), "aid": self.get_aid()}
-        return (await request("GET", url, params=params, credential=self.credential))[
+        return (await Api(**api, credential=self.credential).update_params(**params).result)[
             "multiply"
         ]
 
@@ -448,9 +456,9 @@ class Video:
         """
         self.credential.raise_for_no_sessdata()
 
-        url = API["info"]["has_favoured"]["url"]
+        api = API["info"]["has_favoured"]
         params = {"bvid": self.get_bvid(), "aid": self.get_aid()}
-        return (await request("GET", url, params=params, credential=self.credential))[
+        return (await Api(**api, credential=self.credential).update_params(**params).result)[
             "favoured"
         ]
 
@@ -461,9 +469,9 @@ class Video:
         Returns:
             bool: 是否禁止笔记。
         """
-        url = API["info"]["is_forbid"]["url"]
+        api = API["info"]["is_forbid"]
         params = {"aid": self.get_aid()}
-        return (await request("GET", url, params=params, credential=self.credential))[
+        return (await Api(**api, credential=self.credential).update_params(**params).result)[
             "forbid_note_entrance"
         ]
 
@@ -476,9 +484,9 @@ class Video:
         """
         self.credential.raise_for_no_sessdata()
 
-        url = API["info"]["private_notes"]["url"]
+        api = API["info"]["private_notes"]
         params = {"oid": self.get_aid(), "oid_type": 0}
-        return (await request("GET", url, params=params, credential=self.credential))[
+        return (await Api(**api, credential=self.credential).update_params(**params).result)[
             "noteIds"
         ]
 
@@ -488,15 +496,16 @@ class Video:
 
         Args:
             pn (int): 页码
+
             ps (int): 每页项数
 
         Returns:
             dict: 调用 API 返回的结果。
         """
 
-        url = API["info"]["public_notes"]["url"]
+        api = API["info"]["public_notes"]
         params = {"oid": self.get_aid(), "oid_type": 0, "pn": pn, "ps": ps}
-        return await request("GET", url, params=params, credential=self.credential)
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def get_danmaku_view(
         self, page_index: Union[int, None] = None, cid: Union[int, None] = None
@@ -506,6 +515,7 @@ class Video:
 
         Args:
             page_index (int, optional): 分 P 号，从 0 开始。Defaults to None
+
             cid        (int, optional): 分 P 的 ID。Defaults to None
 
         Returns:
@@ -723,7 +733,9 @@ class Video:
 
         Args:
             page_index (int, optional): 分 P 号，从 0 开始。Defaults to None
+
             date       (datetime.Date | None, optional): 指定日期后为获取历史弹幕，精确到年月日。Defaults to None.
+
             cid        (int | None, optional): 分 P 的 ID。Defaults to None
 
         Returns:
@@ -793,6 +805,15 @@ class Video:
                     if type_ == 4:
                         reader.bytes_string()
                         # 什么鬼？我用 protoc 解析出乱码！
+                    elif type_ == 5:
+                        # 大会员专属颜色
+                        reader.varint()
+                        reader.varint()
+                        reader.varint()
+                        reader.bytes_string()
+                    elif type_ == 13:
+                        # ???
+                        continue
                     else:
                         raise ResponseException("解析响应数据错误")
 
@@ -812,7 +833,12 @@ class Video:
                     elif data_type == 4:
                         dm.font_size = dm_reader.varint()
                     elif data_type == 5:
-                        dm.color = hex(dm_reader.varint())[2:]
+                        color = dm_reader.varint()
+                        if color != 60001:
+                            color = hex(color)[2:]
+                        else:
+                            color = "special"
+                        dm.color = color
                     elif data_type == 6:
                         dm.crc32_id = dm_reader.string()
                     elif data_type == 7:
@@ -829,6 +855,14 @@ class Video:
                         dm.id_str = dm_reader.string()
                     elif data_type == 13:
                         dm.attr = dm_reader.varint()
+                    elif data_type == 14:
+                        dm.uid = dm_reader.varint()
+                    elif data_type == 15:
+                        dm_reader.varint()
+                    elif data_type == 20:
+                        dm_reader.bytes_string()
+                    elif data_type == 21:
+                        dm_reader.bytes_string()
                     else:
                         break
                 danmakus.append(dm)
@@ -842,6 +876,7 @@ class Video:
 
         Args:
             page_index (int, optional)       : 分 P 号. Defaults to 0.
+
             cid        (int | None, optional): 分 P id. Defaults to None.
 
         Returns:
@@ -906,7 +941,9 @@ class Video:
 
         Args:
             page_index (int | None, optional): 分 P 号，从 0 开始。Defaults to None
+
             date       (datetime.date | None): 精确到年月. Defaults to None。
+
             cid        (int | None, optional): 分 P 的 ID。Defaults to None
 
         Returns:
@@ -925,9 +962,7 @@ class Video:
 
         api = API["danmaku"]["get_history_danmaku_index"]
         params = {"oid": cid, "month": date.strftime("%Y-%m"), "type": 1}
-        return await request(
-            "GET", url=api["url"], params=params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def has_liked_danmakus(
         self,
@@ -940,7 +975,9 @@ class Video:
 
         Args:
             page_index (int | None, optional): 分 P 号，从 0 开始。Defaults to None
+
             ids        (List[int] | None): 要查询的弹幕 ID 列表。
+
             cid        (int | None, optional): 分 P 的 ID。Defaults to None
 
         Returns:
@@ -959,9 +996,7 @@ class Video:
 
         api = API["danmaku"]["has_liked_danmaku"]
         params = {"oid": cid, "ids": ",".join(ids)}  # type: ignore
-        return await request(
-            "GET", url=api["url"], params=params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def send_danmaku(
         self,
@@ -974,7 +1009,9 @@ class Video:
 
         Args:
             page_index (int | None, optional): 分 P 号，从 0 开始。Defaults to None
+
             danmaku    (Danmaku | None)      : Danmaku 类。
+
             cid        (int | None, optional): 分 P 的 ID。Defaults to None
 
         Returns:
@@ -1012,9 +1049,7 @@ class Video:
             "mode": danmaku.mode,
             "plat": 1,
         }
-        return await request(
-            "POST", url=api["url"], data=data, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_data(**data).result
 
     async def get_danmaku_xml(
         self, page_index: Union[int, None] = None, cid: Union[int, None] = None
@@ -1024,6 +1059,7 @@ class Video:
 
         Args:
             page_index (int, optional)       : 分 P 序号. Defaults to 0.
+
             cid        (int | None, optional): cid. Defaults to None.
 
         Return:
@@ -1055,8 +1091,11 @@ class Video:
 
         Args:
             page_index (int | None, optional) : 分 P 号，从 0 开始。Defaults to None
+
             dmid       (int | None)           : 弹幕 ID。
+
             status     (bool | None, optional): 点赞状态。Defaults to True
+
             cid        (int | None, optional) : 分 P 的 ID。Defaults to None
 
         Returns:
@@ -1082,9 +1121,7 @@ class Video:
             "op": 1 if status else 2,
             "platform": "web_player",
         }
-        return await request(
-            "POST", url=api["url"], data=data, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_data(**data).result
 
     async def operate_danmaku(
         self,
@@ -1098,8 +1135,11 @@ class Video:
 
         Args:
             page_index (int | None, optional)      : 分 P 号，从 0 开始。Defaults to None
+
             dmids      (List[int] | None)          : 弹幕 ID 列表。
+
             cid        (int | None, optional)      : 分 P 的 ID。Defaults to None
+
             type_      (DanmakuOperatorType | None): 操作类型
 
         Returns:
@@ -1130,9 +1170,7 @@ class Video:
             "state": type_.value,
         }
 
-        return await request(
-            "POST", url=api["url"], data=data, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_data(**data).result
 
     async def like(self, status: bool = True) -> dict:
         """
@@ -1149,9 +1187,7 @@ class Video:
 
         api = API["operate"]["like"]
         data = {"aid": self.get_aid(), "like": 1 if status else 2}
-        return await request(
-            "POST", url=api["url"], data=data, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_data(**data).result
 
     async def pay_coin(self, num: int = 1, like: bool = False) -> dict:
         """
@@ -1159,6 +1195,7 @@ class Video:
 
         Args:
             num  (int, optional) : 硬币数量，为 1 ~ 2 个。Defaults to 1.
+
             like (bool, optional): 是否同时点赞。Defaults to False.
 
         Returns:
@@ -1177,9 +1214,7 @@ class Video:
             "multiply": num,
             "like": 1 if like else 0,
         }
-        return await request(
-            "POST", url=api["url"], data=data, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_data(**data).result
 
     async def triple(self) -> dict:
         """
@@ -1190,7 +1225,7 @@ class Video:
         """
         api = API["operate"]["yjsl"]
         data = {"bvid": self.get_bvid(), "aid": self.get_aid()}
-        return await request("POST", api["url"], data=data, credential=self.credential)
+        return await Api(**api, credential=self.credential).update_data(**data).result
 
     async def add_tag(self, name: str) -> dict:
         """
@@ -1207,9 +1242,7 @@ class Video:
 
         api = API["operate"]["add_tag"]
         data = {"aid": self.get_aid(), "bvid": self.get_bvid(), "tag_name": name}
-        return await request(
-            "POST", url=api["url"], data=data, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_data(**data).result
 
     async def delete_tag(self, tag_id: int) -> dict:
         """
@@ -1227,9 +1260,7 @@ class Video:
         api = API["operate"]["del_tag"]
 
         data = {"tag_id": tag_id, "aid": self.get_aid(), "bvid": self.get_bvid()}
-        return await request(
-            "POST", url=api["url"], data=data, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_data(**data).result
 
     async def appeal(self, reason: Any, detail: str):
         """
@@ -1237,6 +1268,7 @@ class Video:
 
         Args:
             reason (Any): 投诉类型。传入 VideoAppealReasonType 中的项目即可。
+
             detail (str): 详情信息。
 
         Returns:
@@ -1250,7 +1282,7 @@ class Video:
             reason = {"tid": reason}
         data.update(reason)
         # XXX: 暂不支持上传附件
-        return await request("POST", api["url"], data=data, credential=self.credential)
+        return await Api(**api, credential=self.credential).update_data(**data).result
 
     async def set_favorite(
         self, add_media_ids: List[int] = [], del_media_ids: List[int] = []
@@ -1260,6 +1292,7 @@ class Video:
 
         Args:
             add_media_ids (List[int], optional): 要添加到的收藏夹 ID. Defaults to [].
+
             del_media_ids (List[int], optional): 要移出的收藏夹 ID. Defaults to [].
 
         Returns:
@@ -1278,9 +1311,7 @@ class Video:
             "add_media_ids": ",".join(map(lambda x: str(x), add_media_ids)),
             "del_media_ids": ",".join(map(lambda x: str(x), del_media_ids)),
         }
-        return await request(
-            "POST", url=api["url"], data=data, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_data(**data).result
 
     async def get_subtitle(
         self,
@@ -1310,6 +1341,7 @@ class Video:
 
         Args:
             cid (int | None): 分 P ID,从视频信息中获取
+
             epid (int | None): 番剧分集 ID,从番剧信息中获取
 
         Returns:
@@ -1324,10 +1356,7 @@ class Video:
             "cid": cid,
             "ep_id": epid,
         }
-        return await request(
-            "GET", api["url"], params=params, credential=self.credential
-        )
-
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def submit_subtitle(
         self,
@@ -1363,10 +1392,15 @@ class Video:
 
         Args:
             lan        (str)                 : 字幕语言代码，参考 http://www.lingoes.cn/zh/translator/langcode.htm
+
             data       (dict)                : 字幕数据
+
             submit     (bool)                : 是否提交，不提交为草稿
+
             sign       (bool)                : 是否署名
+
             page_index (int | None, optional): 分 P 索引. Defaults to None.
+
             cid        (int | None, optional): 分 P id. Defaults to None.
 
         Returns:
@@ -1394,9 +1428,7 @@ class Video:
             "bvid": self.get_bvid(),
         }
 
-        return await request(
-            "POST", api["url"], data=payload, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_data(**data).result
 
     async def get_danmaku_snapshot(self) -> dict:
         """
@@ -1409,9 +1441,7 @@ class Video:
 
         params = {"aid": self.get_aid()}
 
-        return await request(
-            "GET", api["url"], params=params, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_params(**params).result
 
     async def recall_danmaku(
         self,
@@ -1424,7 +1454,9 @@ class Video:
 
         Args:
             page_index(int | None, optional): 分 P 号
+
             dmid(int)      : 弹幕 id
+
             cid(int | None, optional)       : 分 P 编码
         Returns:
             调用 API 返回的结果
@@ -1441,9 +1473,7 @@ class Video:
         api = API["danmaku"]["recall"]
         data = {"dmid": dmid, "cid": cid}
 
-        return await request(
-            "POST", url=api["url"], data=data, credential=self.credential
-        )
+        return await Api(**api, credential=self.credential).update_data(**data).result
 
     async def get_pbp(
         self, page_index: Union[int, None] = None, cid: Union[int, None] = None
@@ -1453,6 +1483,7 @@ class Video:
 
         Args:
             page_index(int | None): 分 P 号
+
             cid(int | None)       : 分 P 编码
 
         Returns:
@@ -1491,7 +1522,7 @@ class Video:
         datas = {
             "aid": self.get_aid(),
         }
-        return await request("POST", api["url"], data=datas, credential=self.credential)
+        return await Api(**api, credential=self.credential).update_data(**datas).result
 
     async def delete_from_toview(self) -> dict:
         """
@@ -1504,7 +1535,7 @@ class Video:
         self.credential.raise_for_no_bili_jct()
         api = get_api("toview")["operate"]["del"]
         datas = {"viewed": "false", "aid": self.get_aid()}
-        return await request("POST", api["url"], data=datas, credential=self.credential)
+        return await Api(**api, credential=self.credential).update_data(**datas).result
 
 
 class VideoOnlineMonitor(AsyncEvent):
@@ -1573,9 +1604,13 @@ class VideoOnlineMonitor(AsyncEvent):
         """
         Args:
             bvid       (str | None, optional)       : BVID. Defaults to None.
+
             aid        (int | None, optional)       : AID. Defaults to None.
+
             page_index (int, optional)              : 分 P 序号. Defaults to 0.
+
             credential (Credential | None, optional): Credential 类. Defaults to None.
+
             debug      (bool, optional)             : 调试模式，将输出更详细信息. Defaults to False.
         """
         super().__init__()
@@ -1632,11 +1667,9 @@ class VideoOnlineMonitor(AsyncEvent):
         # 获取服务器信息
         self.logger.debug(f"准备连接：{self.__video.get_bvid()}")
         self.logger.debug(f"获取服务器信息中...")
-        resp = await request(
-            "GET",
-            "https://api.bilibili.com/x/web-interface/broadcast/servers?platform=pc",
-            credential=self.credential,
-        )
+
+        api = API["video"]["info"]["video_online_broadcast_servers"]
+        resp = await Api(**api, credential=self.credential).result
 
         uri = f"wss://{resp['domain']}:{resp['wss_port']}/sub"
         self.__heartbeat_interval = resp["heartbeat"]
@@ -2070,15 +2103,25 @@ class VideoDownloadURLDataDetecter:
             **以下参数仅能在音视频流分离的情况下产生作用，flv / mp4 试看流 / html5 mp4 流下以下参数均没有作用**
 
             video_max_quality       (VideoQuality, optional)      : 设置提取的视频流清晰度最大值，设置此参数绝对不会禁止 HDR/杜比. Defaults to VideoQuality._8K.
+
             audio_max_quality       (AudioQuality, optional)      : 设置提取的音频流清晰度最大值. 设置此参数绝对不会禁止 Hi-Res/杜比. Defaults to AudioQuality._192K.
+
             video_min_quality       (VideoQuality, optional)      : 设置提取的视频流清晰度最小值，设置此参数绝对不会禁止 HDR/杜比. Defaults to VideoQuality._360P.
+
             audio_min_quality       (AudioQuality, optional)      : 设置提取的音频流清晰度最小值. 设置此参数绝对不会禁止 Hi-Res/杜比. Defaults to AudioQuality._64K.
+
             video_accepted_qualities(List[VideoQuality], optional): 设置允许的所有视频流清晰度. Defaults to ALL.
+
             audio_accepted_qualities(List[AudioQuality], optional): 设置允许的所有音频清晰度. Defaults to ALL.
+
             codecs                  (List[VideoCodecs], optional) : 设置所有允许提取出来的视频编码. 此项不会忽略 HDR/杜比. Defaults to ALL codecs.
+
             no_dolby_video          (bool, optional)              : 是否禁止提取杜比视界视频流. Defaults to False.
+
             no_dolby_audio          (bool, optional)              : 是否禁止提取杜比全景声音频流. Defaults to False.
+
             no_hdr                  (bool, optional)              : 是否禁止提取 HDR 视频流. Defaults to False.
+
             no_hires                (bool, optional)              : 是否禁止提取 Hi-Res 音频流. Defaults to False.
 
         Returns:
@@ -2206,15 +2249,25 @@ class VideoDownloadURLDataDetecter:
             **以下参数仅能在音视频流分离的情况下产生作用，flv / mp4 试看流 / html5 mp4 流下以下参数均没有作用**
 
             video_max_quality       (VideoQuality)                : 设置提取的视频流清晰度最大值，设置此参数绝对不会禁止 HDR/杜比. Defaults to VideoQuality._8K.
+
             audio_max_quality       (AudioQuality)                : 设置提取的音频流清晰度最大值. 设置此参数绝对不会禁止 Hi-Res/杜比. Defaults to AudioQuality._192K.
+
             video_min_quality       (VideoQuality, optional)      : 设置提取的视频流清晰度最小值，设置此参数绝对不会禁止 HDR/杜比. Defaults to VideoQuality._360P.
+
             audio_min_quality       (AudioQuality, optional)      : 设置提取的音频流清晰度最小值. 设置此参数绝对不会禁止 Hi-Res/杜比. Defaults to AudioQuality._64K.
+
             video_accepted_qualities(List[VideoQuality], optional): 设置允许的所有视频流清晰度. Defaults to ALL.
+
             audio_accepted_qualities(List[AudioQuality], optional): 设置允许的所有音频清晰度. Defaults to ALL.
+
             codecs                  (List[VideoCodecs])           : 设置所有允许提取出来的视频编码. 在数组中越靠前的编码选择优先级越高. 此项不会忽略 HDR/杜比. Defaults to [VideoCodecs.AV1, VideoCodecs.AVC, VideoCodecs.HEV].
+
             no_dolby_video          (bool)                        : 是否禁止提取杜比视界视频流. Defaults to False.
+
             no_dolby_audio          (bool)                        : 是否禁止提取杜比全景声音频流. Defaults to False.
+
             no_hdr                  (bool)                        : 是否禁止提取 HDR 视频流. Defaults to False.
+
             no_hires                (bool)                        : 是否禁止提取 Hi-Res 音频流. Defaults to False.
 
         Returns:
